=====
pyRVT
=====

.. image:: https://img.shields.io/pypi/v/pyrvt.svg
    :target: https://pypi.python.org/pypi/pyrvt
    :alt: PyPi Cheese Shop

.. image:: https://img.shields.io/travis/arkottke/pyrvt.svg
    :target: https://travis-ci.org/arkottke/pyrvt
    :alt: Build Status

.. image:: https://readthedocs.org/projects/pyrvt/badge/?version=latest&style=flat
    :target: https://pyrvt.readthedocs.org
    :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/arkottke/pyrvt/badge.svg?branch=master
    :target: https://coveralls.io/github/arkottke/pyrvt?branch=master
    :alt: Test Coverage

.. image:: https://landscape.io/github/arkottke/pyrvt/master/landscape.svg?style=flat
    :target: https://landscape.io/github/arkottke/pyrvt/master
    :alt: Code Health

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :alt: License
    
.. image:: https://zenodo.org/badge/21452/arkottke/pyrvt.svg
   :target: https://zenodo.org/badge/latestdoi/21452/arkottke/pyrvt
   :alt: DOI Information

A Python library and command-line application for using random vibration theory
to transform between acceleration Fourier amplitude spectrum and acceleration
response spectrum.

* Free software: MIT license
* Documentation: https://pyrvt.readthedocs.org.

Information on the installation and usage can be found in the documentation_.

.. _documentation: http://pyrvt.readthedocs.org/

Features
--------

Peak factor implementations:

* Vanmarcke (1975)

* Davenport (1964)

* Der Kiureghian (1985)

* Toro & McGuire (1987)

* Cartwright & Longuet-Higgins (1956)

* Boore & Joyner (1984)

* Liu & Pezeshk (1999)


Citation
--------
Please cite this software using the following DOI:

.. image:: https://zenodo.org/badge/21452/arkottke/pyrvt.svg
   :target: https://zenodo.org/badge/latestdoi/21452/arkottke/pyrvt
   :alt: DOI Information
